netapp_ontap.models.ndmp_data API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.ndmp_data`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class NdmpDataSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NdmpData object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `bytes_processed GET POST PATCH`

    Indicates the NDMP data bytes processed.

    Example: 5000

  `connection GET POST PATCH`

    Indicates the NDMP connection attributes.

  `operation GET POST PATCH`

    Indicates the NDMP data server operation.

    Valid choices:

    - backup
    - restore
    - none
  `reason GET POST PATCH`

    Indicates the reason for the NDMP data server halt.

  `state GET POST PATCH`

    Indicates the state of the NDMP data server.